@@ -1,13 +1,26 @@
+# Copyright (C) 2009-2012 Adam Vandenberg <flangy@gmail.com>
+#                         Ask Solem <askh@modwheel.net>
+#                         Barthelemy Dagenais <bart@cs.mcgill.ca>
+#                         Fernando Perez <Fernando.Perez@berkeley.edu>
+#                         James Rowe <jnrowe@gmail.com>
+#                         Scott Torborg <scott@crookedmedia.com>
+#
+# This file is part of python-github2, and is made available under the 3-clause
+# BSD license.  See LICENSE for the full details.
+
 try:
     from urllib.parse import quote_plus  # For Python 3
 except ImportError:
-    from urllib import quote_plus
+    from urllib import quote_plus  # NOQA
 
 from github2.core import (GithubCommand, BaseData, Attribute, DateAttribute,
                           repr_string, requires_auth)
 
 
 class Issue(BaseData):
+
+    """Issue container."""
+
     position = Attribute("The position of this issue in a list.")
     number = Attribute("The issue number (unique for project).")
     votes = Attribute("Number of votes for this issue.")
@@ -28,6 +41,9 @@ class Issue(BaseData):
 
 
 class Comment(BaseData):
+
+    """Comment container."""
+
     created_at = DateAttribute("The date this comment was created.")
     updated_at = DateAttribute("The date when this comment was last updated.")
     body = Attribute("The full text of this comment.")
@@ -39,6 +55,9 @@ class Comment(BaseData):
 
 
 class Issues(GithubCommand):
+
+    """GitHub API issues functionality."""
+
     domain = "issues"
 
     def search(self, project, term, state="open"):
@@ -48,7 +67,8 @@ class Issues(GithubCommand):
 
         :param str project: GitHub project
         :param str term: term to search issues for
-        :param str state: can be either ``open`` or ``closed``.
+        :param str state: can be either ``open`` or ``closed``
+
         """
         return self.get_values("search", project, state, quote_plus(term),
                                filter="issues", datatype=Issue)
@@ -57,7 +77,8 @@ class Issues(GithubCommand):
         """Get all issues for project with given state.
 
         :param str project: GitHub project
-        :param str state: can be either ``open`` or ``closed``.
+        :param str state: can be either ``open`` or ``closed``
+
         """
         return self.get_values("list", project, state, filter="issues",
                                datatype=Issue)
@@ -68,7 +89,8 @@ class Issues(GithubCommand):
         .. versionadded:: 0.3.0
 
         :param str project: GitHub project
-        :param str label:  a string representing a label (e.g., ``bug``).
+        :param str label:  a string representing a label (e.g., ``bug``)
+
         """
         return self.get_values("list", project, "label", label,
                                filter="issues", datatype=Issue)
@@ -79,6 +101,7 @@ class Issues(GithubCommand):
         .. versionadded:: 0.3.0
 
         :param str project: GitHub project
+
         """
         return self.get_values("labels", project, filter="labels")
 
@@ -86,7 +109,8 @@ class Issues(GithubCommand):
         """Get all the data for issue by issue-number.
 
         :param str project: GitHub project
-        :param int number: issue number in the Github database
+        :param int number: issue number in the GitHub database
+
         """
         return self.get_value("show", project, str(number),
                               filter="issue", datatype=Issue)
@@ -98,6 +122,7 @@ class Issues(GithubCommand):
         :param str project: GitHub project
         :param str title: title for issue
         :param str body: body for issue
+
         """
         issue_data = {"title": title, "body": body}
         return self.get_value("open", project, post_data=issue_data,
@@ -105,36 +130,39 @@ class Issues(GithubCommand):
 
     @requires_auth
     def close(self, project, number):
-        """Close an issue
+        """Close an issue.
 
         :param str project: GitHub project
-        :param int number: issue number in the Github database
+        :param int number: issue number in the GitHub database
+
         """
         return self.get_value("close", project, str(number), filter="issue",
                               datatype=Issue, method="POST")
 
     @requires_auth
     def reopen(self, project, number):
-        """Reopen a closed issue
+        """Reopen a closed issue.
 
         .. versionadded:: 0.3.0
 
         :param str project: GitHub project
-        :param int number: issue number in the Github database
+        :param int number: issue number in the GitHub database
+
         """
         return self.get_value("reopen", project, str(number), filter="issue",
                               datatype=Issue, method="POST")
 
     @requires_auth
     def edit(self, project, number, title, body):
-        """Edit an existing issue
+        """Edit an existing issue.
 
         .. versionadded:: 0.3.0
 
         :param str project: GitHub project
-        :param int number: issue number in the Github database
+        :param int number: issue number in the GitHub database
         :param str title: title for issue
         :param str body: body for issue
+
         """
         issue_data = {"title": title, "body": body}
         return self.get_value("edit", project, str(number),
@@ -143,22 +171,24 @@ class Issues(GithubCommand):
 
     @requires_auth
     def add_label(self, project, number, label):
-        """Add a label to an issue
+        """Add a label to an issue.
 
         :param str project: GitHub project
-        :param int number: issue number in the Github database
+        :param int number: issue number in the GitHub database
         :param str label: label to attach to issue
+
         """
         return self.get_values("label/add", project, label, str(number),
                                filter="labels", method="POST")
 
     @requires_auth
     def remove_label(self, project, number, label):
-        """Remove an existing label from an issue
+        """Remove an existing label from an issue.
 
         :param str project: GitHub project
-        :param int number: issue number in the Github database
+        :param int number: issue number in the GitHub database
         :param str label: label to remove from issue
+
         """
         return self.get_values("label/remove", project, label, str(number),
                                filter="labels", method="POST")
@@ -168,8 +198,9 @@ class Issues(GithubCommand):
         """Comment on an issue.
 
         :param str project: GitHub project
-        :param int number: issue number in the Github database
+        :param int number: issue number in the GitHub database
         :param str comment: comment to attach to issue
+
         """
         comment_data = {'comment': comment}
         return self.get_value("comment", project, str(number),
@@ -180,7 +211,7 @@ class Issues(GithubCommand):
         """View comments on an issue.
 
         :param str project: GitHub project
-        :param int number: issue number in the Github database
+
         """
         return self.get_values("comments", project, str(number),
                                filter="comments", datatype=Comment)
